#!/usr/bin/env python
#
# Turn a list into a list of unique and sorted entries

import collections

def uniqsort(seq):
    """Sort the unique elements in the supplied sequence
    >>> uniqsort([9, 5, 4, 5, 3, 6, 1])
    [1, 3, 4, 5, 6, 9]
    """
    return sorted(list(set(seq)))
    

def uniqc(seq):
    """Return a list of (unique element and count of element)
    >>> uniqc(["blue", "red", "blue", "white", "black", "blue", "red"])
    [('blue', 3), ('red', 2), ('white', 1), ('black', 1)]
    """
    count = collections.Counter(seq) 
    data = count.most_common()
    return data


def uniqcr(seq, reversed = False):
    """Return a list of (unique element and count of element) and can reverse the order
    in which the list is assembled so least frequent elements are listed first
    >>> uniqcr(["blue", "red", "blue", "white", "black", "blue", "red"])
    [('blue', 3), ('red', 2), ('white', 1), ('black', 1)]
    >>> uniqcr(["blue", "red", "blue", "white", "black", "blue", "red"], reversed = True)
    [('black', 1), ('white', 1), ('red', 2), ('blue', 3)]
    """
    count = collections.Counter(seq) 
    data = count.most_common()
    if reversed:
        data.reverse()
    return data

# ------------------------------------------------------------------------------

if __name__ == '__main__':
    import doctest
    doctest.testmod()

